# filelistener - Duplicate Content Finder

filelistener is a Python package to find duplicate content within a folder and its subdirectories. Including zips

## Installation

You can install filelistener using pip:

```
pip install filelistener
```

## Usage
To check for duplicate files, use the filelistener command with the -f flag followed by the folder path:

```
listen -f /path/to/folder -s
```

```
listen -h
```
